@@ -283,6 +283,10 @@ class TestGetData:
                                           filtered_column_date_format,
                                           custom_date_start_val,
                                           custom_date_end_val):
+        if filtered_column_nm not in get_three_good_field_ids:
+            get_three_good_field_ids.append(filtered_column_nm)
+        else:
+            get_three_good_field_ids
         connector.authenticate()
         data = connector.get_data(good_object_id,
                                   get_three_good_field_ids,
